#include "qlistmodel.h"

QListModel::QListModel(QObject *parent) :
    QAbstractListModel(parent)
{
    //Инициализация данных модели по умолчанию
    list << 33 << 55 << 77;
}

int QListModel::rowCount(const QModelIndex &parent) const
{
    //Возвращает кол-во элементов модели
    return list.count();
}

QVariant QListModel::data(const QModelIndex &index, int role) const
{
    //Случай невалидного индекса
    if (!index.isValid())
        return QVariant();

    //Получает значение по индексу
    int value = list.at(index.row());

    switch (role){
    //Для отображения и редактирования значения
    case Qt::DisplayRole:
    case Qt::EditRole:
        return value;
    //Устанавливает размеры элемента
    case Qt::SizeHintRole:
        return QSize(0, 30);
    //Устанавливает всплывающий текст
    case Qt::ToolTipRole:
        return QString::number(value);
    //Устанавливает выравнивание текста в ячейке
    case Qt::TextAlignmentRole:
        return Qt::AlignCenter;
    //Устанавливает шрифт текста
    case Qt::FontRole:
        return QFont("Times New Roman", 12, QFont::Bold);
    //Устанавливает цвет заднего фона элемента
    case Qt::BackgroundRole:
        if (value < 30)
            return QBrush(Qt::red);
        else if (value < 60)
            return QBrush(Qt::yellow);
        else
            return QBrush(Qt::green);
    default:
        return QVariant();
    }
}

bool QListModel::setData(const QModelIndex &index, const QVariant &value, int role)
{
    //Сохраняет отредактированное значение в данных модели
    if (role == Qt::EditRole)
        list.replace(index.row(), value.toInt());
}

Qt::ItemFlags QListModel::flags(const QModelIndex &index) const
{
    if (!index.isValid())
        return Qt::NoItemFlags;
    //Возвращает свойства элемента: активность, выделяемость, редактируемость
    return Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsEditable;
}

QVariant QListModel::headerData(int section, Qt::Orientation orientation, int role) const
{
    //Устанавливает текст (в данном случае его отсутствие) в заголовке представления
    return QVariant();
}
